@@ -939,7 +939,6 @@ if (!strncmp(name, "GL_", 3)) {
 	i(GL_COLOR_TABLE_ALPHA_SIZE_EXT)
 	i(GL_COLOR_TABLE_LUMINANCE_SIZE_EXT)
 	i(GL_COLOR_TABLE_INTENSITY_SIZE_EXT)
-	i(GL_TEXTURE_INDEX_SIZE_EXT)
 	i(GL_COLOR_INDEX1_EXT)
 	i(GL_COLOR_INDEX2_EXT)
 	i(GL_COLOR_INDEX4_EXT)
@@ -2166,10 +2165,6 @@ if (!strncmp(name, "GL_", 3)) {
 	i(GL_OPERAND2_ALPHA_EXT)
 	i(GL_LIGHT_MODEL_SPECULAR_VECTOR_APPLE)
 	i(GL_TRANSFORM_HINT_APPLE)
-#if defined(GL_SGIX_fog_scale)
-	i(GL_FOG_SCALE_SGIX)
-	i(GL_FOG_SCALE_VALUE_SGIX)
-#endif
 	i(GL_UNPACK_CONSTANT_DATA_SUNX)
 	i(GL_TEXTURE_CONSTANT_DATA_SUNX)
 	i(GL_GLOBAL_ALPHA_SUN)
@@ -3079,6 +3074,44 @@ if (!strncmp(name, "GL_", 3)) {
 	i(MAX_GL_FOG_COUNT)
 	i(MAX_GL_GET_COUNT)
 
+#ifdef GL_VERSION_1_3
+	i(GL_TEXTURE0)
+	i(GL_TEXTURE1)
+	i(GL_TEXTURE2)
+	i(GL_TEXTURE3)
+	i(GL_TEXTURE4)
+	i(GL_TEXTURE5)
+	i(GL_TEXTURE6)
+	i(GL_TEXTURE7)
+	i(GL_TEXTURE8)
+	i(GL_TEXTURE9)
+	i(GL_TEXTURE10)
+	i(GL_TEXTURE11)
+	i(GL_TEXTURE12)
+	i(GL_TEXTURE13)
+	i(GL_TEXTURE14)
+	i(GL_TEXTURE15)
+	i(GL_TEXTURE16)
+	i(GL_TEXTURE17)
+	i(GL_TEXTURE18)
+	i(GL_TEXTURE19)
+	i(GL_TEXTURE20)
+	i(GL_TEXTURE21)
+	i(GL_TEXTURE22)
+	i(GL_TEXTURE23)
+	i(GL_TEXTURE24)
+	i(GL_TEXTURE25)
+	i(GL_TEXTURE26)
+	i(GL_TEXTURE27)
+	i(GL_TEXTURE28)
+	i(GL_TEXTURE29)
+	i(GL_TEXTURE30)
+	i(GL_TEXTURE31)
+	i(GL_ACTIVE_TEXTURE)
+	i(GL_CLIENT_ACTIVE_TEXTURE)
+	i(GL_MAX_TEXTURE_UNITS)
+#endif
+
 #ifdef GL_VERSION_2_1
 	i(CURRENT_RASTER_SECONDARY_COLOR)
 	i(FLOAT_MAT2x3)
