@@ -338,10 +338,8 @@ sub ourPrintString
 # Does everything needed before losing control to the main
 # OpenGL event loop.
 
-sub ourInit
+sub ourInitVertexBuffers
 {
-  my ($Width, $Height) = @_;
-
   # Set initial colors for rainbow face
   for (my $i=0; $i<16; $i++)
   {
@@ -352,6 +350,8 @@ sub ourInit
   # Initialize VBOs if supported
   if ($hasVBO)
   {
+    printf("Using VBOs\n");
+
     ($VertexObjID,$NormalObjID,$ColorObjID,$TexCoordObjID,$IndexObjID) =
       glGenBuffersARB_p(5);
 
@@ -399,12 +399,21 @@ sub ourInit
   }
   else
   {
+    print "Using classic Vertex Buffers\n";
     glVertexPointer_p(3, $verts);
     glNormalPointer_p($norms);
     $colors->assign($rainbow_offset,@rainbow);
     glColorPointer_p(4, $colors);
     glTexCoordPointer_p(2, $texcoords);
   }
+  print "-- done\n";
+}
+
+sub ourInit
+{
+  my ($Width, $Height) = @_;
+
+  printf("\nUsing POGL v$Acme::MITHALDU::BleedingOpenGL::VERSION\n");
 
   # Build texture.
   ($TextureID_image,$TextureID_FBO) = glGenTextures_p(2);
@@ -414,6 +423,9 @@ sub ourInit
   # Initialize shaders.
   ourInitShaders();
 
+  # Initialize vertex buffers
+  ourInitVertexBuffers();
+
   # Initialize rendering parameters
   glEnable(GL_TEXTURE_2D);
   glDisable(GL_LIGHTING);
@@ -457,7 +469,6 @@ sub ourBuildTextures
 
   # Build Image Texture
   ($TextureID_image,$TextureID_FBO) = glGenTextures_p(2);
-  print "\n";
 
   # Use OpenGL::Image to load texture
   if ($hasImage && -e $Tex_File)
@@ -612,6 +623,8 @@ sub ourBuildTextures
   # Build FBO texture
   if ($hasFBO)
   {
+    printf("Using FBOs\n");
+
     ($FrameBufferID) = glGenFramebuffersEXT_p(1);
     ($RenderBufferID) = glGenRenderbuffersEXT_p(1);
 
@@ -656,9 +669,22 @@ sub ourInitShaders
 {
   # Setup Vertex/Fragment Programs to render FBO texture
 
-  # Use OpenGL::Shader
-  if ($hasShader && ($Shader = new OpenGL::Shader()))
+  if ($hasShader)
   {
+    my $version = $OpenGL::Shader::VERSION;
+    printf("Using OpenGL::Shader v$version\n");
+    my $types = OpenGL::Shader->GetTypes();
+    my @types = keys(%$types);
+    printf("This installation supports the following shader types: %s\n", join(',', @types));
+
+    # Use OpenGL::Shader
+    $Shader = new OpenGL::Shader();
+    if (!$Shader)
+    {
+      printf("Unable to instantiate OpenGL::Shader\n");
+      return;
+    }
+
     my $type = $Shader->GetType();
     my $ext = lc($type);
 
@@ -674,10 +700,10 @@ sub ourInitShaders
       print "$stat\n";
     }
   }
-
   # Fall back to doing it manually
-  if ($hasFragProg)
+  elsif ($hasFragProg)
   {
+    printf("Using native OpenGL ARB Shader functions\n");
     ($VertexProgID,$FragProgID) = glGenProgramsARB_p(2);
 
     # NOP Vertex shader
